summaryrefslogtreecommitdiff
path: root/src/soc/intel/common
diff options
context:
space:
mode:
authorWonkyu Kim <wonkyu.kim@intel.com>2021-09-15 15:52:51 -0700
committerTim Wawrzynczak <twawrzynczak@chromium.org>2021-10-26 18:12:17 +0000
commitaaec8095b92e315a0502a027879352517f72f329 (patch)
tree960e2ed43cfc2840598890f50101c29672a44456 /src/soc/intel/common
parent74f4e48e855c665adcf161c8367a9fb92d069047 (diff)
soc/intel: Update api name for getting spi destination id
Update api name and comments to be more generic as spi destination id is not DMI specific. Update api name as soc_get_spi_psf_destination_id and comments. And move PSF definition from pcr_ids.h as it's not pcr id. Signed-off-by: Wonkyu Kim <wonkyu.kim@intel.com> Change-Id: Ie338d05649d23bddae5355dc6ce8440dfb183073 Reviewed-on: https://review.coreboot.org/c/coreboot/+/58433 Tested-by: build bot (Jenkins) <no-reply@coreboot.org> Reviewed-by: Tim Wawrzynczak <twawrzynczak@chromium.org> Reviewed-by: Jamie Ryu <jamie.m.ryu@intel.com>
Diffstat (limited to 'src/soc/intel/common')
-rw-r--r--src/soc/intel/common/block/fast_spi/fast_spi.c4
-rw-r--r--src/soc/intel/common/block/include/intelblocks/fast_spi.h4
2 files changed, 4 insertions, 4 deletions
diff --git a/src/soc/intel/common/block/fast_spi/fast_spi.c b/src/soc/intel/common/block/fast_spi/fast_spi.c
index 93de2ecb87..0e012316d1 100644
--- a/src/soc/intel/common/block/fast_spi/fast_spi.c
+++ b/src/soc/intel/common/block/fast_spi/fast_spi.c
@@ -325,9 +325,9 @@ static void fast_spi_enable_ext_bios(void)
"Only 32MiB windows are supported for extended BIOS!");
#endif
- /* Configure DMI Source decode for Extended BIOS Region */
+ /* Configure Source decode for Extended BIOS Region */
if (dmi_enable_gpmr(CONFIG_EXT_BIOS_WIN_BASE, CONFIG_EXT_BIOS_WIN_SIZE,
- soc_get_spi_dmi_destination_id()) == CB_ERR)
+ soc_get_spi_psf_destination_id()) == CB_ERR)
return;
/* Program EXT_BIOS_BAR1 with obtained ext_bios_base */
diff --git a/src/soc/intel/common/block/include/intelblocks/fast_spi.h b/src/soc/intel/common/block/include/intelblocks/fast_spi.h
index d5d3cd560c..a903ea839e 100644
--- a/src/soc/intel/common/block/include/intelblocks/fast_spi.h
+++ b/src/soc/intel/common/block/include/intelblocks/fast_spi.h
@@ -87,9 +87,9 @@ void fast_spi_disable_wp(void);
*/
void fast_spi_get_ext_bios_window(uintptr_t *base, size_t *size);
/*
* SOC function to get SPI-DMI Destination Id
*/
-uint32_t soc_get_spi_dmi_destination_id(void);
+uint32_t soc_get_spi_psf_destination_id(void);
/*
* Add MTRR for extended BIOS region(when supported) to postcar frame
*/
@@ -87,9 +87,9 @@ void fast_spi_disable_wp(void);
void fast_spi_get_ext_bios_window(uintptr_t *base, size_t *size);
/*
- * SOC function to get SPI-DMI Destination Id
+ * SOC function to get SPI PSF Destination Id
*/